@@ -11,8 +11,8 @@ from metaphor.models.metadata_change_event import (
     DatasetLogicalID,
     DatasetSchema,
     DatasetStatistics,
-    DatasetUpstream,
     DbtMacro,
+    DbtMacroArgument,
     DbtMaterialization,
     DbtMaterializationType,
     DbtModel,
@@ -22,7 +22,6 @@ from metaphor.models.metadata_change_event import (
     MetadataChangeEvent,
     SchemaField,
     SchemaType,
-    SQLSchema,
     VirtualView,
     VirtualViewLogicalID,
     VirtualViewType,
@@ -46,18 +45,11 @@ logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
 
-@dataclass
-class DbtDataset:
-    database: str
-    schema: str
-    name: str
-
-
 @deserialize
 @dataclass
 class DbtRunConfig(RunConfig):
     manifest: str
-    catalog: str
+    catalog: Optional[str] = None
 
     # the database service account this DBT project is connected to
     account: Optional[str] = None
@@ -74,7 +66,7 @@ class DbtExtractor(BaseExtractor):
         self.platform: DataPlatform = DataPlatform.UNKNOWN
         self.account: Optional[str] = None
         self._manifest: DbtManifest
-        self._catalog: DbtCatalog
+        self._catalog: Optional[DbtCatalog] = None
         self._datasets: Dict[str, Dataset] = {}
         self._virtual_views: Dict[str, VirtualView] = {}
 
@@ -90,11 +82,12 @@ class DbtExtractor(BaseExtractor):
             logger.error(f"Read manifest json error: {e}")
             raise e
 
-        try:
-            self._catalog = DbtCatalog.parse_file(Path(config.catalog))
-        except Exception as e:
-            logger.error(f"Read catalog json error: {e}")
-            raise e
+        if config.catalog:
+            try:
+                self._catalog = DbtCatalog.parse_file(Path(config.catalog))
+            except Exception as e:
+                logger.error(f"Read catalog json error: {e}")
+                raise e
 
         self._parse_manifest()
 
@@ -133,111 +126,39 @@ class DbtExtractor(BaseExtractor):
             if isinstance(v, CompiledSchemaTestNode)
         }
 
-        dataset_map = {}
-        for key, model in models.items():
-            assert model.database is not None
-            dataset_map[key] = DbtDataset(model.database, model.schema_, model.name)
-        for key, source in sources.items():
-            assert source.database is not None
-            dataset_map[key] = DbtDataset(source.database, source.schema_, source.name)
-
-        for model in models.values():
-            self._parse_model(model, dataset_map)
-
-        for test in tests.values():
-            self._parse_test(test)
-
         self._parse_manifest_nodes(sources, macros, tests, models)
 
-    def _parse_model(
-        self,
-        model: CompiledModelNode,
-        dataset_map: Dict[str, DbtDataset],
-    ) -> None:
-        assert model.database is not None
-        dataset = self._init_dataset(
-            model.database, model.schema_, model.name, model.unique_id
-        )
-        self._init_schema(dataset)
-
-        if model.compiled_sql is not None:
-            assert dataset.schema is not None
-            dataset.schema.sql_schema = SQLSchema()
-            dataset.schema.sql_schema.table_schema = model.compiled_sql
-
-        if model.description is not None:
-            dataset.schema.description = model.description
-            self._init_documentation(dataset)
-            assert (
-                dataset.documentation is not None
-                and dataset.documentation.dataset_documentations is not None
-            )
-            dataset.documentation.dataset_documentations.append(model.description)
-
-        if model.columns is not None:
-            for col in model.columns.values():
-                column_name = col.name.lower()
-                field = self._init_field(dataset.schema.fields, column_name)
-                field.description = col.description
-                field.native_type = (
-                    "Not Set" if col.data_type is None else col.data_type
-                )
-
-                if col.description:
-                    field_doc = self._init_field_doc(dataset, column_name)
-                    field_doc.documentation = col.description
-
-        if model.depends_on is not None:
-            dataset.upstream = DatasetUpstream()
-            dataset.upstream.source_code_url = model.original_file_path
-
-            if model.depends_on.nodes is not None:
-                dataset.upstream.source_datasets = [
-                    self._get_dataset_id(dataset_map[n]) for n in model.depends_on.nodes
-                ]
-
-    def _parse_test(self, test: CompiledSchemaTestNode) -> None:
-        if test.test_metadata is None:
-            return
-
-        if test.depends_on is None or not test.depends_on.nodes:
-            return
-
-        depends_on_model = test.depends_on.nodes[0]
-        if depends_on_model not in self._datasets:
-            return
-
-        dataset = self._datasets[depends_on_model]
-
-        columns = []
-        if test.columns:
-            columns = list(test.columns.keys())
-        elif test.column_name is not None:
-            columns = [test.column_name]
-
-        for column in columns:
-            field_doc = self._init_field_doc(dataset, column)
-            if not field_doc.tests:
-                field_doc.tests = []
-            field_doc.tests.append(test.test_metadata.name)
-
     def _parse_catalog(self) -> None:
         if self._catalog is None:
             return
 
-        nodes = self._catalog.nodes
-        sources = self._catalog.sources
+        for node in self._catalog.nodes.values():
+            self._parse_catalog_model(node)
 
-        for model in {**nodes, **sources}.values():
-            self._parse_catalog_model(model)
+        for source in self._catalog.sources.values():
+            self._parse_catalog_source(source)
 
     def _parse_catalog_model(self, model: CatalogTable):
+        assert model.unique_id is not None
+
+        virtual_view = self._init_virtual_view(model.unique_id)
+        dbt_model = virtual_view.dbt_model
+
+        dbt_model.description = dbt_model.description or model.metadata.comment
+
+        for col in model.columns.values():
+            column_name = col.name.lower()
+            field = self._init_field(dbt_model.fields, column_name)
+            field.description = field.description or col.comment
+            field.native_type = field.native_type or col.type or "Not Set"
+
+    def _parse_catalog_source(self, model: CatalogTable):
         meta = model.metadata
         columns = model.columns
-        stats = model.stats
 
-        assert meta.database is not None
         assert model.unique_id is not None
+        assert meta.database is not None
+
         dataset = self._init_dataset(
             meta.database, meta.schema_, meta.name, model.unique_id
         )
@@ -247,19 +168,20 @@ class DbtExtractor(BaseExtractor):
         # assert dataset.ownership is not None and dataset.ownership.people is not None
         # dataset.ownership.people.append(self._build_owner(meta["owner"]))
 
-        self._init_schema(dataset)
         self._init_documentation(dataset)
+        if meta.comment:
+            dataset.documentation.dataset_documentations = [meta.comment]
 
         for col in columns.values():
-            column_name = col.name.lower()
-            field = self._init_field(dataset.schema.fields, column_name)
-            field.description = col.comment
-            field.native_type = "Not Set" if col.type is None else col.type
-
             if col.comment:
+                column_name = col.name.lower()
                 field_doc = self._init_field_doc(dataset, column_name)
                 field_doc.documentation = col.comment
 
+    @staticmethod
+    def _parse_catalog_statistics(dataset: Dataset, model: CatalogTable):
+        stats = model.stats
+
         has_stats = stats.get("has_stats")
         if has_stats is not None and has_stats.value is not None:
             statistics = DatasetStatistics()
@@ -303,16 +225,31 @@ class DbtExtractor(BaseExtractor):
         source_map = {}
         for key, source in sources.items():
             assert source.database is not None
-            source_map[key] = DbtDataset(source.database, source.schema_, source.name)
+            source_map[key] = self._get_dataset_entity_id(
+                source.database, source.schema_, source.name
+            )
 
         macro_map = {}
         for key, macro in macros.items():
+            arguments = (
+                [
+                    DbtMacroArgument(
+                        name=arg.name,
+                        type=arg.type,
+                        description=arg.description,
+                    )
+                    for arg in macro.arguments
+                ]
+                if macro.arguments
+                else []
+            )
+
             macro_map[key] = DbtMacro(
                 name=macro.name,
                 unique_id=macro.unique_id,
                 package_name=macro.package_name,
                 description=macro.description,
-                arguments=macro.arguments,
+                arguments=arguments,
                 sql=macro.macro_sql,
                 depends_on_macros=macro.depends_on.macros if macro.depends_on else None,
             )
@@ -338,8 +275,10 @@ class DbtExtractor(BaseExtractor):
             if materialized:
                 dbt_model.materialization = DbtMaterialization(
                     type=DbtMaterializationType[materialized.upper()],
-                    target_dataset=self._get_dataset_id(
-                        DbtDataset(model.database, model.schema_, model.name)
+                    target_dataset=str(
+                        self._get_dataset_entity_id(
+                            model.database, model.schema_, model.name
+                        )
                     ),
                 )
 
@@ -348,9 +287,7 @@ class DbtExtractor(BaseExtractor):
                     column_name = col.name.lower()
                     field = self._init_field(dbt_model.fields, column_name)
                     field.description = col.description
-                    field.native_type = (
-                        "Not Set" if col.data_type is None else col.data_type
-                    )
+                    field.native_type = col.data_type or "Not Set"
 
             if model.depends_on is not None:
                 if model.depends_on.nodes:
@@ -361,7 +298,7 @@ class DbtExtractor(BaseExtractor):
                     ]
 
                     dbt_model.source_datasets = [
-                        self._get_dataset_id(source_map[n])
+                        str(source_map[n])
                         for n in model.depends_on.nodes
                         if n.startswith("source.")
                     ]
@@ -394,21 +331,21 @@ class DbtExtractor(BaseExtractor):
 
             self._init_dbt_tests(model_unique_id).append(dbt_test)
 
-    @staticmethod
-    def _dataset_name(db: str, schema: str, table: str) -> str:
-        return f"{db}.{schema}.{table}".lower()
+    def _get_dataset_logical_id(
+        self, db: str, schema: str, table: str
+    ) -> DatasetLogicalID:
+        full_name = f"{db}.{schema}.{table}".lower()
 
-    def _get_dataset_id(self, dataset: DbtDataset) -> str:
-        dataset_name = DbtExtractor._dataset_name(
-            dataset.database, dataset.schema, dataset.name
-        )
-
-        dataset_id = DatasetLogicalID(
-            name=dataset_name,
+        return DatasetLogicalID(
+            name=full_name,
             platform=self.platform,
             account=self.account,
         )
-        return str(EntityId(EntityType.DATASET, dataset_id))
+
+    def _get_dataset_entity_id(self, db: str, schema: str, table: str) -> EntityId:
+        return EntityId(
+            EntityType.DATASET, self._get_dataset_logical_id(db, schema, table)
+        )
 
     @staticmethod
     def _get_virtual_view_id(logical_id: VirtualViewLogicalID) -> str:
@@ -424,11 +361,7 @@ class DbtExtractor(BaseExtractor):
     ) -> Dataset:
         if unique_id not in self._datasets:
             self._datasets[unique_id] = Dataset(
-                logical_id=DatasetLogicalID(
-                    name=self._dataset_name(database, schema, name),
-                    platform=self.platform,
-                    account=self.account,
-                )
+                logical_id=self._get_dataset_logical_id(database, schema, name)
             )
         return self._datasets[unique_id]
 
