@@ -45,37 +45,13 @@ class Connection:
 @dataclass
 class Explore:
     name: str
-    upstream_datasets: Set[EntityId]
-    description: Optional[str]
-    label: Optional[str]
 
     @staticmethod
     def from_dict(
-        raw_explore: Dict, raw_views: Dict[str, Dict], connection: Connection
+        raw_explore: Dict,
     ):
-        explore_name = raw_explore["name"]
-
-        # The underlying view of an explore can be specified via "from" or "view_name".
-        # When not specified, it's default to the same name as the explore itself.
-        # See https://docs.looker.com/reference/explore-params/from-for-explore
-        view_name = raw_explore.get("from", raw_explore.get("view_name", explore_name))
-        upstream_datasets = _get_upstream_datasets(view_name, raw_views, connection)
-
-        # zero or more joins
-        for join in raw_explore.get("joins", []):
-            # The actual view name may be overridden via "from".
-            # See https://docs.looker.com/reference/explore-params/join
-            join_view_name = join.get("from", join["name"])
-
-            upstream_datasets.update(
-                _get_upstream_datasets(join_view_name, raw_views, connection)
-            )
-
         return Explore(
-            name=explore_name,
-            description=raw_explore.get("description", None),
-            label=raw_explore.get("label", None),
-            upstream_datasets=upstream_datasets,
+            name=raw_explore["name"],
         )
 
 
@@ -85,14 +61,12 @@ class Model:
 
     @staticmethod
     def from_dict(
-        raw_views: Dict[str, Dict],
         raw_explores: Dict[str, Dict],
-        connection: Connection,
     ):
         explores = [
             # Ignore refinements since they don't change the sources
             # See https://docs.looker.com/data-modeling/learning-lookml/refinements
-            Explore.from_dict(raw_explore, raw_views, connection)
+            Explore.from_dict(raw_explore)
             for raw_explore in raw_explores.values()
             if not raw_explore["name"].startswith("+")
         ]
@@ -177,12 +151,16 @@ def _extract_upstream_datasets_from_sql(
     return upstream
 
 
+def fullname(model: str, name: str) -> str:
+    return f"{model}.{name}"
+
+
 def _build_looker_view(
-    raw_view: Dict, raw_views: Dict[str, Dict], connection: Connection
+    model: str, raw_view: Dict, raw_views: Dict[str, Dict], connection: Connection
 ) -> VirtualView:
     name = raw_view["name"]
     view = LookerView(
-        label=raw_view.get("label", None),
+        label=raw_view.get("label"),
         source_datasets=[
             str(ds) for ds in _get_upstream_datasets(name, raw_views, connection)
         ],
@@ -190,7 +168,11 @@ def _build_looker_view(
 
     if "extends" in raw_view:
         view.extends = [
-            str(to_virtual_view_entity_id(view, VirtualViewType.LOOKER_VIEW))
+            str(
+                to_virtual_view_entity_id(
+                    fullname(model, view), VirtualViewType.LOOKER_VIEW
+                )
+            )
             for view in raw_view["extends"]
         ]
 
@@ -213,28 +195,37 @@ def _build_looker_view(
         ]
 
     return VirtualView(
-        logical_id=VirtualViewLogicalID(name=name, type=VirtualViewType.LOOKER_VIEW),
+        logical_id=VirtualViewLogicalID(
+            name=fullname(model, name), type=VirtualViewType.LOOKER_VIEW
+        ),
         looker_view=view,
     )
 
 
-def _build_looker_explore(raw_explore: Dict) -> VirtualView:
+def _build_looker_explore(model: str, raw_explore: Dict) -> VirtualView:
     name = raw_explore["name"]
-    base_view_name = raw_explore.get("view_name", raw_explore.get("from", name))
+    base_view_name = raw_explore.get("from", raw_explore.get("view_name", name))
 
     explore = LookerExplore(
-        description=raw_explore.get("description", None),
-        label=raw_explore.get("label", None),
-        tags=raw_explore.get("tags", None),
-        fields=raw_explore.get("fields", None),
+        model_name=model,
+        description=raw_explore.get("description"),
+        label=raw_explore.get("label"),
+        tags=raw_explore.get("tags"),
+        fields=raw_explore.get("fields"),
         base_view=str(
-            to_virtual_view_entity_id(base_view_name, VirtualViewType.LOOKER_VIEW)
+            to_virtual_view_entity_id(
+                fullname(model, base_view_name), VirtualViewType.LOOKER_VIEW
+            )
         ),
     )
 
     if "extends" in raw_explore:
         explore.extends = [
-            str(to_virtual_view_entity_id(explore, VirtualViewType.LOOKER_EXPLORE))
+            str(
+                to_virtual_view_entity_id(
+                    fullname(model, explore), VirtualViewType.LOOKER_EXPLORE
+                )
+            )
             for explore in raw_explore["extends"]
         ]
 
@@ -243,13 +234,13 @@ def _build_looker_explore(raw_explore: Dict) -> VirtualView:
             LookerExploreJoin(
                 view=str(
                     to_virtual_view_entity_id(
-                        raw_join.get("from", raw_join["name"]),
+                        fullname(model, raw_join.get("from", raw_join["name"])),
                         VirtualViewType.LOOKER_VIEW,
                     )
                 ),
-                fields=raw_join.get("fields", None),
-                on_clause=raw_join.get("sql_on", None),
-                where_clause=raw_join.get("sql_where", None),
+                fields=raw_join.get("fields"),
+                on_clause=raw_join.get("sql_on"),
+                where_clause=raw_join.get("sql_where"),
                 type=raw_join.get("type", "left_outer"),
                 relationship=raw_join.get("relationship", "many_to_one"),
             )
@@ -259,7 +250,9 @@ def _build_looker_explore(raw_explore: Dict) -> VirtualView:
     # TODO: combine access_filters, always_filters and conditional_filters into explore.filters
 
     return VirtualView(
-        logical_id=VirtualViewLogicalID(name=name, type=VirtualViewType.LOOKER_EXPLORE),
+        logical_id=VirtualViewLogicalID(
+            name=fullname(model, name), type=VirtualViewType.LOOKER_EXPLORE
+        ),
         looker_explore=explore,
     )
 
@@ -336,14 +329,17 @@ def parse_project(
 
         virtual_views.extend(
             [
-                _build_looker_view(view, raw_views, connection)
+                _build_looker_view(model_name, view, raw_views, connection)
                 for view in raw_views.values()
             ]
         )
         virtual_views.extend(
-            [_build_looker_explore(explore) for explore in raw_explores.values()]
+            [
+                _build_looker_explore(model_name, explore)
+                for explore in raw_explores.values()
+            ]
         )
 
-        model_map[model_name] = Model.from_dict(raw_views, raw_explores, connection)
+        model_map[model_name] = Model.from_dict(raw_explores)
 
     return model_map, virtual_views
